# youtube-analyzer

Obtenha detalhes completos de vídeos do YouTube com esta biblioteca incrível!
<br>


### Funcionalidades
- [x] Obter detalhes de um vídeo
- [x] Obter legendas
- [x] Tradução de legendas
- [x] Analisar playlists
- [x] Obter detalhes de URIs de vídeos
- [x] Downloads de áudios e vídeos

<br>

Acesse a [Documentação aqui](https://github.com/PauloCesar-dev404/youtube_analyzer/blob/main/Docs/document.md)



### Contribuições
Se tiver dúvidas ou sugestões, abra uma [issue aqui](https://github.com/PauloCesar-dev404/youtube_analyzer/issues).


